pacman-game
===========

A pacman game built entirely in python.

Build Badge
-----------

[![Build Status](https://travis-ci.org/ParthKolekar/pacman-game.svg?branch=master)](https://travis-ci.org/ParthKolekar/pacman)
[![Coverage Status](https://coveralls.io/repos/ParthKolekar/pacman-game/badge.svg)](https://coveralls.io/r/ParthKolekar/pacman)
[![Bitdeli Badge](https://d2weczhvl823v0.cloudfront.net/ParthKolekar/pacman-game/trend.png)](https://bitdeli.com/free "Bitdeli Badge")

